| analyze | R Documentation |
mp_data using lme4::lmerAnalyzes a single mp_data based on the data generating model.
analyze(data, alpha = 0.05, no_lrt = FALSE, ...)
data |
a |
alpha |
the significance level to determine if an effect is statistically significant.
If |
no_lrt |
do not perform additional likelihood ratio tests.
Setting to |
... |
other arguments passed to |
A list that with the following named elements:
estimates: The estimates from fitting the model.
sig_test: The logical if the estimates were statistically siginificant based on alpha.
parameters: The mp_parameters extracted from data.
# Create Model
model <- (
outcome('Y')
+ within_predictor('X')
+ effect_size(icc = 0.1)
)
# Set seed
set.seed(198723)
# Create data set and analyze
model |> generate(5, 50) |> analyze() -> results
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.